@@ -7,13 +7,14 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub info {
 	return (
-		first_name     => '明日香',
-		family_name    => '福田',
-		pronunciation  => 'Fukuda Asuka',
+		first_name_ja  => '明日香',
+		family_name_ja => '福田',
+		first_name_en  => 'Asuka',
+		family_name_en => 'Fukuda',
 		nick           => [qw(あすか 焼き銀杏)],
 		birthday       => Date::Simple->new('1984-12-17'),
 		blood_type     => 'B',
