@@ -7,13 +7,14 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub info {
 	return (
-		first_name     => '里沙',
-		family_name    => '新垣',
-		pronunciation  => 'Niigaki Risa',
+		first_name_ja  => '里沙',
+		family_name_ja => '新垣',
+		first_name_en  => 'Risa',
+		family_name_en => 'Niigaki',
 		nick           => [qw(垣さん お豆ちゃん)],
 		birthday       => Date::Simple->new('1988-10-20'),
 		blood_type     => 'B',
