@@ -7,13 +7,14 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub info {
 	return (
-		first_name     => '真琴',
-		family_name    => '小川',
-		pronunciation  => 'Ogawa Makoto',
+		first_name_ja  => '麻琴',
+		family_name_ja => '小川',
+		first_name_en  => 'Makoto',
+		family_name_en => 'Ogawa',
 		nick           => [qw(マコッちゃん)],
 		birthday       => Date::Simple->new('1987-10-29'),
 		blood_type     => 'O',
