@@ -7,13 +7,14 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub info {
 	return (
-		first_name     => 'ひとみ',
-		family_name    => '吉澤',
-		pronunciation  => 'YoshizawaHitomi',
+		first_name_ja  => 'ひとみ',
+		family_name_ja => '吉澤',
+		first_name_en  => 'Hitomi',
+		family_name_en => 'Yoshizawa',
 		nick           => [qw(よっすぃー)],
 		birthday       => Date::Simple->new('1985-04-12'),
 		blood_type     => 'O',
